@@ -37,7 +37,7 @@ def sql(key):
         'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
         'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin" AND status != 0;', 'database': 'AnyRobot'},
         'JDBCCollectorId': {
-            'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='jdbc' AND JDBCCollectorConfig.`sql`='select * from AgentHost';",
+            'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='mysqljdbc' AND JDBCCollectorConfig.`sql`='select * from AgentHost';",
             'database': 'AnyRobot'},
         'vSphereID': {
             'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vSphere' AND config LIKE '%192.168.0.250%';",
