@@ -82,7 +82,7 @@ def filed(key,inquire=[]):
         'FutureTime': ParaDateFiledServer().getFutureTime,
         'RoleId_user': DataManage.DataManage_Storage().RoleId_user,
         'mailUser':testMail.date().getMailUser,
-        'mailpass':testMail.date().getMailPass
+        'mailPass':testMail.date().getMailPass
     }
 
     switcher = SERVICE_KPI_
